pub struct MetricsAPIHandler { /* private fields */ }Expand description
An API handler for updating metric filtering directives at runtime.
This handler exposes two main routes – /metrics/override and /metrics/reset – which allow for
overriding the default metric filtering directives (configured at startup) at runtime, and then resetting them once
the override is no longer needed.
As this has the potential for incredibly high metrics cardinality at runtime, the override is set with a specific duration in which it will apply. Once an override has been active for the configured duration, it will automatically be reset unless the override is refreshed before the duration elapses.
The maximum duration for an override is 60 minutes.