MetricsOverrideWorker

Struct MetricsOverrideWorker 

pub struct MetricsOverrideWorker { /* private fields */ }
A worker that processes dynamic metric filter override requests.

When running, the worker asserts a set of routes (based on MetricsAPIHandler) that allow triggering an override of the current metrics filter directives as well as clearing (resetting) the active override.