pub async fn collect_runtime_metrics(runtime_id: &str, handle: Handle)Expand description
Collects Tokio runtime metrics from the given runtime handle.
All metrics generated will include a runtime_id label which maps to the given runtime ID. This allows for
differentiating between multiple runtimes that may be running in the same process.